pub(crate) fn key_data_parts(key_data: KeyData) -> Result<(u32, u32), Failed>Expand description
Decode a slotmap::KeyData into its version and index components.
Note that the version value here will include the trailing LSB=1 value,
to indicate that it is for an occupied slot.
The caller should right-shift the version result by 1
to get the actual “version” of the slot
(as we define “version” in the rest of this crate).