macro_rules! shared_no_ops {
{} => { ... };
}Expand description
Helper: Define the common members of Ser and SerU32.
(These are just a bunch of methods that return Err(Failed))
macro_rules! shared_no_ops {
{} => { ... };
}Helper: Define the common members of Ser and SerU32.
(These are just a bunch of methods that return Err(Failed))