macro_rules! define_implementation {
{ $mapname:ident } => { ... };
}Expand description
Helper: Define a wrapper for a single SlotMap type.
This works for SlotMap, and DenseSlotMap.
(The alternative to using a macro here would be to define a new trait implemented by all of the SlotMaps, and then to define our own SlotMap as a wrapper around an instance of that trait.)